@@ -24,7 +24,6 @@ use_pyvista = False
 tstart = time.time()
 timings = {}
 
-
 testdir = 'examples/'
 
 
@@ -199,7 +198,7 @@ k.showMesh()
 #k.createSurvey(testdir + 'dc-3d/protocol.dat', ftype='ProtocolDC')
 #k.createMesh()
 
-# 3D cylinder
+#%% 3D cylinder
 # radius = 6.5/2 # cm
 # angles = np.linspace(0, 2*np.pi, 13)[:-1] # radian
 # celec = np.c_[radius*np.cos(angles), radius*np.sin(angles)]
@@ -207,7 +206,7 @@ k.showMesh()
 k = Project(typ='R3t')
 # k.setElec(elec)
 k.importElec(testdir + 'dc-3d-cylinder/elec.csv')
-k.createMesh('cylinder', zlim=[0, 47.5], cl=0.8)
+k.createMesh('cylinder', zlim=[0, 47.5], cl=0.4, cl_factor=3)
 # k.importSequence(testdir + 'dc-3d-cylinder/sequence.csv')
 k.createSequence([('custSeq', testdir + 'dc-3d-cylinder/sequence.csv')])
 k.forward()
@@ -215,7 +214,7 @@ k.saveMesh(os.path.join(k.dirname, 'mesh.vtk'))
 k.saveMesh(os.path.join(k.dirname, 'mesh.node'))
 k.saveMesh(os.path.join(k.dirname, 'mesh.dat'))
 
-# 3D tank
+#%% 3D tank
 elec = np.array([[0,2,2],[0,2,6],[0,3,2],[0,3,6],
                   [10,2,2],[10,2,6],[10,3,2],[10,3,6],
                   [3,0,2],[5,0,2],[7,0,2],[3,0,6],[5,0,6],[7,0,6],
@@ -619,6 +618,7 @@ a = k.mesh.elmCentre
 idx = (a[:,1]<0.45) & (a[:,1]>-0.45) & (a[:,0]<0.45) & (a[:,0]>-0.45) # set a zone of different resistivity 
 res0 = np.array(k.mesh.df['res0'])
 res0[idx] = 50
+res0[np.invert(idx)] = 200 
 k.setRefModel(res0) # set parameters for forward model 
 
 k.showMesh(attr='res0',color_map='jet',use_pyvista=use_pyvista)
@@ -661,7 +661,8 @@ t0 = time.time()
 k = Project(typ='R3t')
 k.createSurvey(testdir + 'dc-3d-timelapse-column/protocol.dat', ftype='ProtocolDC')
 k.importElec(testdir + 'dc-3d-timelapse-column/elec.csv')
-k.importMesh(testdir + 'dc-3d-timelapse-column/mesh.msh')
+# k.importMesh(testdir + 'dc-3d-timelapse-column/mesh.msh')
+k.createMesh(typ='cylinder',cl=0.005,finer=4)
 k.param['num_xy_poly'] = 0
 k.param['zmin'] = -np.inf
 k.param['zmax'] = np.inf
